package PVE::AuthCookieHandler;

use strict;

use Carp;
use CGI '3.12';
use mod_perl2 '1.9922';

use Apache::AuthCookie::Util;
use Apache2::RequestRec;
use Apache2::RequestUtil;
use Apache2::Log;
use Apache2::Access;
use Apache2::Response;
use Apache2::Util;
use APR::Table;
use Apache2::Const qw(:common M_GET HTTP_FORBIDDEN HTTP_MOVED_TEMPORARILY);
use URI::Escape;
use Digest::SHA1;
use PVE::SafeSyslog;
use PVE::Utils;
use PVE::ConfigServer;
use base qw(Apache2::AuthCookie);
use Encode;

sub authen_cred {
    my $self = shift;
    my $r = shift;
    my ($username, $password) = @_;

    # login.pl encodes data in uft-8
 
    my $ticket;
    eval { $ticket = PVE::ConfigClient::request_ticket ($username, $password); };
    my $err = $@;

    if ($err) {
	syslog ('err', "login failure: $err");
	return undef;
    }

    return PVE::Utils::sign_soap_ticket ($ticket);
}

sub authen_ses_key {
    my $self = shift;
    my $r = shift;
    my $session_key = shift;

    my $uri = $r->uri;

    my ($username, $group, $age, $mac) = PVE::Utils::verify_web_ticket ($session_key);

    if ($username && $group) {

	# update session key
	# - but not for web services
	# - only if older than 2 minutes
	if ($age > 120 && $uri !~ m|^/ws/|) {
	    syslog ('info', "update ticket");

	    my $ticket;
	    eval { 
		$ticket = PVE::ConfigClient::update_ticket ($session_key); 
		$session_key = PVE::Utils::sign_soap_ticket ($ticket);
		$self->send_cookie ($r, $session_key);
	    };
	    my $err = $@;

	    syslog ('err', "update ticket failed: $err") if $err;
	}

	return $username;
    }

    return undef;
}

sub group {
    my ($self, $r, $args) = @_;

    my $cookie = $self->key ($r);

    my ($username, $group) = split /::/, $cookie;

    if ($args eq $group) {
	return OK;
    }

    return FORBIDDEN;
}


sub login_form {  
  my ($self, $r) = @_;

  my $uri = $r->uri;

  # no login for for web services
  if ($uri =~ m|^/ws/|) {
      my $code = AUTH_REQUIRED;
      $r->custom_response($code, '');
      return $code;
  }

  return $self->SUPER::login_form ($r);
}

1;
